@@ -50,11 +50,7 @@ class NaPoleonBinanceFutureBot(object):
         self.cancel_all_order('TRX/USDT')
 
 
-    def get_balance_snapshot(self, request_date):
-        request_date = request_date.replace(hour=0, minute=0, second=0, microsecond=0)
-        start_time = request_date
-        end_time = request_date + timedelta(days = 1)
-
+    def get_futures_balance_history(self, start_time, end_time):
         startTime = int(start_time.timestamp() * 1000)
         endTime = int(end_time.timestamp() * 1000)
 
@@ -97,12 +93,19 @@ class NaPoleonBinanceFutureBot(object):
         concatenated_df['date'] = pd.to_datetime(concatenated_df['updateTime'], unit='ms')
         concatenated_df['date'] = concatenated_df['date'] + timedelta(seconds=1)
 
-        concatenated_df = concatenated_df[concatenated_df['date'] == request_date]
-
         return concatenated_df
 
 
 
+    def get_futures_balance_snapshot(self, request_date):
+        request_date = request_date.replace(hour=0, minute=0, second=0, microsecond=0)
+        start_time = request_date
+        end_time = request_date + timedelta(days = 1)
+        result_df = self.get_futures_balance_history(start_time, end_time)
+        result_df = result_df[result_df['date'] == request_date]
+        return result_df
+
+
     def get_futures_transfer_history(self, assets, start_time, end_time):
         transfer_df = None
         for asset in assets:
