@@ -72,6 +72,22 @@ def compute_last_signal(rolled_df, lookback_window, function_to_apply):
     last_signal = function_to_apply(last_rolling_df)
     return last_signal
 
+
+def drop_positions(signal_df, max_period_to_keep_position):
+    a = signal_df.copy()
+    a.columns = ['y']
+    df = a.copy()
+    s = df['y'].diff().ne(0).cumsum()
+    first_rows = ~s.duplicated()
+
+    df = df[first_rows]
+
+    idx = pd.date_range(a.index.min(), a.index.max())
+    df = df.reindex(idx)
+    df = df.fillna(method="ffill", limit=max_period_to_keep_position)
+    df = df[df.index.isin(s.index)]
+    return df
+
 def roll_wrapper(rolled_df, lookback_window, skipping_size, function_to_apply, trigger):
     signal_df = roll(rolled_df, lookback_window).apply(function_to_apply)
     signal_df = signal_df.to_frame()
@@ -85,7 +101,7 @@ def roll_wrapper(rolled_df, lookback_window, skipping_size, function_to_apply, t
     rolled_df = rolled_df.iloc[skipping_size:]
     return rolled_df
 
-def roll_cointegration_wrapper(rolled_df, lookback_window, skipping_size, function_to_apply, trigger, suffixes):
+def roll_cointegration_wrapper(rolled_df, lookback_window, keep_same_position_periods, skipping_size, function_to_apply, trigger, suffixes):
     x_suffixe,y_suffixe = suffixes
     signal_gen_x, signal_gen_y = 'signal_gen' + x_suffixe, 'signal_gen' + y_suffixe
     signal_x, signal_y = 'signal' + x_suffixe, 'signal' + y_suffixe
@@ -94,6 +110,9 @@ def roll_cointegration_wrapper(rolled_df, lookback_window, skipping_size, functi
     signal_df.columns = ['signal']
     signal_df[[signal_gen_x, signal_gen_y]] = pd.DataFrame(signal_df['signal'].tolist(), index=signal_df.index)
     signal_df[[signal_x, signal_y]] = signal_df[[signal_gen_x, signal_gen_y]].shift()
+    signal_df[signal_x] = drop_positions(signal_df[[signal_x]], keep_same_position_periods)
+    signal_df[signal_y] = drop_positions(signal_df[[signal_y]], keep_same_position_periods)
+
     if trigger:
         signal_df[signal_x] = signal_df[signal_x].fillna(method='ffill')
         signal_df[signal_y] = signal_df[signal_y].fillna(method='ffill')
