@@ -437,6 +437,23 @@ def fetch_all_necessary_data(public_key = None, private_key= None, start_time= N
 
     ohlc_bnb_min_binance = binance_get(public_key, private_key, 'spot_klines', start_time, end_time=end_time, symbol ='BNBUSDT', aggreg ='1m')
 
+    fut_transfers = binance_get_futures_transfer_histo(public_key, private_key, start_time, end_time)
+    fut_transfers['date'] = fut_transfers['date'].dt.floor('H')
+    fut_transfers = pd.merge(fut_transfers, ohlc_bnb_min_binance[['ts', 'open']], how='left', left_on='date',
+                               right_on='ts')
+
+    def convert_trans_bnb_to_usdt(row):
+        print(row)
+        if row['asset'] == 'BNB':
+            return float(row['amount']) * float(row['open'])
+        elif row['asset'] == 'USDT':
+            return float(row['amount'])
+        else :
+            return np.nan
+    fut_transfers['fut_transfer_usdt_amount'] = fut_transfers.apply(convert_trans_bnb_to_usdt, axis=1)
+    fut_transfers = fut_transfers[['date','fut_transfer_usdt_amount']].groupby('date').sum()
+
+
     history_balance = binance_get_future_balance_history(public_key,private_key,start_time, end_time)
 
     history_balance = pd.merge(history_balance, ohlc_bnb_min_binance[['ts','open']], how='left', left_on = 'date', right_on = 'ts')
@@ -457,7 +474,6 @@ def fetch_all_necessary_data(public_key = None, private_key= None, start_time= N
     converted_history_balance = history_balance[['ts','convertedWalletBalance']].groupby('ts').sum()
 
 
-    fut_transfers = binance_get_futures_transfer_histo(public_key, private_key, start_time, end_time)
     trades = binance_get(public_key, private_key, 'trade_history', start_time, end_time=end_time, symbol ='ETHUSDT').drop_duplicates()
     ohlc_eth_binance = binance_get(public_key, private_key, 'futures_klines', start_time, end_time= end_time, symbol ='ETHUSDT', aggreg ='1m')
     ohlc_btc_binance = binance_get(public_key, private_key, 'futures_klines', start_time, end_time= end_time, symbol ='BTCUSDT', aggreg ='1m')
@@ -482,6 +498,13 @@ def fetch_all_necessary_data(public_key = None, private_key= None, start_time= N
         dbx.upload(fullname=full_path, folder='', subfolder='', name=balance_pkl_file_name, overwrite=True)
         os.remove(full_path)
 
+        full_path = local_root_directory + transfer_pkl_file_name
+        fut_transfers.to_pickle(full_path)
+        print(f'uploading to dropbox {full_path}')
+        dbx.upload(fullname=full_path, folder='', subfolder='', name=transfer_pkl_file_name, overwrite=True)
+        os.remove(full_path)
+
+
         full_path = local_root_directory + trade_pkl_file_name
         trades.to_pickle(full_path)
         print(f'uploading to dropbox {full_path}')
@@ -633,35 +656,20 @@ def fetch_all_necessary_data(public_key = None, private_key= None, start_time= N
     wh = wh.groupby('dt_floor_h').sum()
     wh['pnl'] = wh['realized_pnl']
 
-    if fut_transfers is None:
-        wh['transfer_usd_bis'] = 0.
-    else:
-        wh['transfer_usd_bis'] = 0.
 
 
-    if fut_transfers is not None:
-        fut_transfers_bnb = fut_transfers[fut_transfers['asset'] == 'BNB'].copy()
-        fut_transfers_bnb = fut_transfers_bnb.set_index('date')
-        fut_transfers_bnb['dt_floor_h'] = fut_transfers_bnb.index.map(lambda x: x.floor('H'))
-        fut_transfers_bnb = fut_transfers_bnb.groupby('dt_floor_h').sum()
-
-
-        fut_transfers_usd = fut_transfers[fut_transfers['asset'] == 'USDT'].copy()
-        fut_transfers_usd = fut_transfers_usd.set_index('date')
-        fut_transfers_usd['dt_floor_h'] = fut_transfers_usd.index.map(lambda x: x.floor('H'))
-        fut_transfers_usd = fut_transfers_usd.groupby('dt_floor_h').sum()
-
-
-        fut_transfers_usd = fut_transfers_usd[['amount']].copy()
-        fut_transfers_usd.columns = ['amount_futures_transfer_usd']
-
-        fut_transfers_bnb = fut_transfers_bnb[['amount']].copy()
-        fut_transfers_bnb.columns = ['amount_futures_transfer_bnb']
-
-        wh = pd.merge(wh, fut_transfers_usd, how='left', left_index=True, right_index=True)
-        wh = pd.merge(wh, fut_transfers_bnb, how='left', left_index=True, right_index=True)
-
     wh['date'] = wh.index
+    wh['bench'] = 1.
+    fut_transfers_old = fut_transfers.copy()
+    fut_transfers = pd.merge(fut_transfers, wh[['date', 'bench']], how='outer', left_on='date', right_on='date')
+    fut_transfers = fut_transfers.sort_values(by='date')
+    fut_transfers['fut_transfer_usdt_amount'] = fut_transfers['fut_transfer_usdt_amount'].shift()
+    fut_transfers = fut_transfers.dropna()
+    fut_transfers = fut_transfers.drop(columns=['bench'])
+
+    wh = wh.drop(columns=['bench'])
+    wh = pd.merge(wh, fut_transfers, how='left', left_on='date', right_on='date')
+    wh['fut_transfer_usdt_amount'] = wh['fut_transfer_usdt_amount'].fillna(0.)
     wh = pd.merge(wh, converted_history_balance, how='left', left_on='date', right_on ='ts')
 
     wh = wh.rename(columns={"convertedWalletBalance": "wallet_balance"})
@@ -673,11 +681,23 @@ def fetch_all_necessary_data(public_key = None, private_key= None, start_time= N
     wh.at[wh.index[starting_index], 'realized_pnl'] = wh.at[wh.index[starting_index], 'wallet_balance']
 
     wh['net_profit'] = wh.realized_pnl + wh.funding_fees_eth_usd + wh.funding_fees_xbt_usd + wh.trading_fees_eth_usd + wh.trading_fees_xbt_usd
-    wh['valuation'] = wh.net_profit + wh.transfers_usd
+    wh['valuation'] = wh.net_profit + wh.fut_transfer_usdt_amount
     wh['valuation'] = wh.valuation.cumsum()
 
     td['date'] = td.index
 
+    wh = wh.drop(columns=['fut_transfer_usdt_amount'])
+    td = pd.merge(td, wh, how='left', left_on='date', right_on='date')
+
+    td['bench'] = 1.
+
+    fut_transfers_old = pd.merge(fut_transfers_old, td[['date', 'bench']], how='outer', left_on='date', right_on='date')
+    fut_transfers_old = fut_transfers_old.sort_values(by='date')
+    fut_transfers_old['fut_transfer_usdt_amount'] = fut_transfers_old['fut_transfer_usdt_amount'].shift()
+    fut_transfers_old = fut_transfers_old.dropna()
+
+    td = pd.merge(td, fut_transfers_old, how='left', left_on='date', right_on='date')
+
     td = pd.merge(td, wh, how='left', left_on='date', right_on='date')
 
     td['amount_traded_usd_eth'] = td.traded_eth * td.avg_eth_price
@@ -685,7 +705,7 @@ def fetch_all_necessary_data(public_key = None, private_key= None, start_time= N
 
     x = td[['traded_eth', 'avg_eth_price', 'amount_traded_usd_eth', 'sens_trade_eth', 'open_eth_cc', 'open_eth_bnc',
             'traded_xbt', 'avg_btc_price', 'amount_traded_usd_btc', 'sens_trade_xbt', 'open_btc_cc', 'open_btc_bnc',
-            'valuation', 'transfers_usd','wallet_balance',
+            'valuation', 'fut_transfer_usdt_amount','wallet_balance',
             'trading_fees_eth_usd', 'funding_fees_eth_usd', 'slippage_eth_price_cc', 'slippage_eth_cash_cc','slippage_eth_price_bnc', 'slippage_eth_cash_bnc',
             'trading_fees_xbt_usd', 'funding_fees_xbt_usd', 'slippage_btc_price_cc', 'slippage_btc_cash_cc','slippage_btc_price_bnc', 'slippage_btc_cash_bnc' ]]
 
